@@ -11,11 +11,8 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::Prepender;
-BEGIN {
-  $Dist::Zilla::Plugin::Prepender::VERSION = '1.112280';
-}
 # ABSTRACT: prepend lines at the top of your perl files
-
+$Dist::Zilla::Plugin::Prepender::VERSION = '2.000';
 use Moose;
 use MooseX::Has::Sugar;
 
@@ -51,6 +48,12 @@ sub munge_file {
         return if $file->name =~ $skip;
     }
 
+    if ($file->does('Dist::Zilla:Role::MutableFile'))
+    {
+        $self->log_debug($file->name . ' is not a mutable type, skipping...');
+        return;
+    }
+
     return $self->_munge_perl($file) if $file->name    =~ /\.(?:pm|pl)$/i;
     return $self->_munge_perl($file) if $file->content =~ /^#!(?:.*)perl(?:$|\s)/;
     return;
@@ -108,17 +111,19 @@ __PACKAGE__->meta->make_immutable;
 no Moose;
 1;
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::Plugin::Prepender - prepend lines at the top of your perl files
 
 =head1 VERSION
 
-version 1.112280
+version 2.000
 
 =head1 SYNOPSIS
 
@@ -202,7 +207,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
